@@ -23,10 +23,10 @@ Bio::Community::Tools::Rarefier - Normalize communities by count
   );
 
   # Rarefied results, with decimal counts
-  my $average_community = $rarefier->get_avg_meta->[0];
+  my $average_community = $rarefier->get_avg_meta->next_community;
 
   # Round counts to integer numbers
-  my $representative_community = $rarefier->get_repr_meta->[0];
+  my $representative_community = $rarefier->get_repr_meta->next_community;
   
 
   # Alternatively, specify a number of repetitions
@@ -95,7 +95,9 @@ methods. Internal methods are usually preceded with a _
  Usage   : my $rarefier = Bio::Community::Tool::Rarefier->new( );
  Args    : -metacommunity  : see metacommunity()
            -num_repetitions: see num_repetitions()
+           -threshold      : see threshold()
            -sample_size    : see sample_size()
+           -drop           : see drop()
            -seed           : see set_seed()
  Returns : a new Bio::Community::Tools::Rarefier object
 
@@ -110,10 +112,12 @@ use MooseX::StrictConstructor;
 use namespace::autoclean;
 use Bio::Community::Meta;
 use Bio::Community::Meta::Beta;
-use POSIX;
 use List::Util qw(min);
 use Method::Signatures;
 
+use POSIX; # defines DBL_EPSILON to something like 2.22044604925031e-16
+use constant REL_EPSILON => 1 + 10 * DBL_EPSILON;
+
 extends 'Bio::Root::Root';
 with 'Bio::Community::Role::PRNG';
 
@@ -140,10 +144,11 @@ has metacommunity => (
 
 =head2 sample_size
 
- Function: Get or set the sample size, i.e. the number of members to pick randomly
-           at each iteration. It has to be smaller than the total count of the
-           smallest community or an error will be generated. If the sample size
-           is omitted, it defaults to the get_members_count() of the smallest community.
+ Function: Get or set the sample size, i.e. the number of members to pick
+           randomly at each iteration. It has to be smaller than or equal to the
+           total count of the smallest community or an error will be generated.
+           If the sample size is omitted, it defaults to the get_members_count()
+           of the smallest community.
  Usage   : my $sample_size = $rarefier->sample_size;
  Args    : integer for the sample size
  Returns : integer for the sample size
@@ -199,7 +204,7 @@ has threshold => (
            accessed using this method. As a special case, specify 'inf' to
            simulate an infinite number of repetitions.
  Usage   : my $repetitions = $rarefier->repetitions;
- Args    : positive integer or 'inf' number of repetitions
+ Args    : positive integer or 'inf' for the number of repetitions
  Returns : positive integer for the (minimum) number of repetitions
 
 =cut
@@ -285,7 +290,7 @@ has average_meta => (
    is => 'rw',
    isa => 'Maybe[Bio::Community::Meta]',
    required => 0,
-   default => sub { undef },
+   default => undef,
    lazy => 1,
    reader => 'get_avg_meta',
    writer => '_set_avg_meta',
@@ -368,7 +373,7 @@ method _count_normalize () {
       $sample_size = int $min;
       $self->sample_size($sample_size); 
    } else {
-      if ($sample_size > $min) {
+      if ($sample_size / REL_EPSILON > $min * REL_EPSILON) { # sample_size > min
          my $name;
          for my $community (@$communities) {
             if ($community->get_members_count == $min) {
@@ -402,13 +407,10 @@ method _count_normalize () {
    for my $community ( @$communities ) {
       my ($average, $repetitions, $beta_val);
       my $count = $community->get_members_count;
-      if ($count > $sample_size) {
-         ($average, $repetitions, $beta_val) = $self->_bootstrap($community);
-      } elsif ($count == $sample_size) {
-         ($average, $repetitions, $beta_val) = ($community->clone, undef, undef);
-      } else {
+      if ($sample_size / REL_EPSILON > $count * REL_EPSILON) { # sample_size > min
          next; # drop this community
       }
+      ($average, $repetitions, $beta_val) = $self->_bootstrap($community);
       my $name = $community->name;
       #$name .= ' ' if $name;
       #$name .= 'average';
